@@ -1,5 +1,5 @@
 /*
- * SPDX-FileCopyrightText: Copyright (c) 1993-2024 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
+ * SPDX-FileCopyrightText: Copyright (c) 1993-2025 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
  * SPDX-License-Identifier: MIT
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
@@ -30,6 +30,7 @@
 #include "dp_wardatabase.h"
 #include "dp_edid.h"
 #include "dp_connectorimpl.h"
+#include "dp_connectorimpl2x.h"
 #include "dp_printf.h"
 
 using namespace DisplayPort;
@@ -67,21 +68,15 @@ void ConnectorImpl::applyOuiWARs()
         // Synaptics
         case 0x24CC90:
             if ((modelName[0] == 'S') && (modelName[1] == 'Y') && (modelName[2] == 'N') &&
-                (modelName[3] == 'A') && (modelName[4] == 'S') &&
+                (modelName[3] == 'A') && (((modelName[4] == 'S') &&
                 ((modelName[5] == '1') || (modelName[5] == '2') ||
                  (modelName[5] == '3') || (modelName[5] == '#') ||
-                 (modelName[5] == '\"')))
+                 (modelName[5] == '\"')))||((modelName[4] == 0x84) &&
+                 (modelName[5] == '0'))))
             {
                 //
                 // Extended latency from link-train end to FEC enable pattern
                 // to avoid link lost or blank screen with Synaptics branch.
-                // (Bug 2561206)
-                //
-                // Dock SKU ID:
-                // Dell    Salomon-WD19TB SYNAS1
-                // HP      Hook           SYNAS3
-                // HP      Adira-A        SYNAS#
-                // Lenovo                 SYNAS" / SYNAS2
                 //
                 LT2FecLatencyMs = 57;
 
@@ -99,9 +94,29 @@ void ConnectorImpl::applyOuiWARs()
     }
 }
 
+void ConnectorImpl2x::applyOuiWARs()
+{
+    switch (ouiId)
+    {
+        // Novatek Microelectronics Corp.
+        case 0x11EC38:
+            if((modelName[0] == 'N') && (modelName[1] == 'T') && (modelName[2] == '6'))
+            {
+                NvU8 portType;
+                if (hal->getSupportsMultistream() &&
+                    hal->isDp2xChannelCodingCapable() &&
+                    !hal->getDownstreamPort(&portType))
+                {
+                    bMstTimeslotBug4968411 = true;
+                    hal->setMainLinkChannelCoding(ChannelCoding128B132B);
+                }
+            }
+            break;
+    }
+}
+
 void Edid::applyEdidWorkArounds(NvU32 warFlag, const DpMonitorDenylistData *pDenylistData)
 {
-
     unsigned ManufacturerID = this->getManufId();
     unsigned ProductID = this->getProductId();
     unsigned YearWeek = this->getYearWeek();
@@ -191,8 +206,8 @@ void Edid::applyEdidWorkArounds(NvU32 warFlag, const DpMonitorDenylistData *pDen
             if ((ProductID >= 0x0776 ) && (ProductID <= 0x0779)) // Product id's range from decimal 1910 to 1913
             {
                 // if detailed pixel clock frequency = 106.50MHz
-                if ( (buffer.data[0x36] == 0x9A) &&
-                     (buffer.data[0x37] == 0x29) )
+                if ((buffer.data[0x36] == 0x9A) &&
+                    (buffer.data[0x37] == 0x29) )
                 {
                     // then change detailed pixel clock frequency to 106.54MHz to fix bug 343870
                     buffer.data[0x36] = 0x9E;
@@ -258,7 +273,7 @@ void Edid::applyEdidWorkArounds(NvU32 warFlag, const DpMonitorDenylistData *pDen
                 //    a "Monitor Description" of type FE = "ASCII Data String" which
                 //    has this panel's name = "LP171WX2-A4K5".
                 //
-                if ( (buffer.data[0x71] == 0x4C) &&
+                if ((buffer.data[0x71] == 0x4C) &&
                     (buffer.data[0x72] == 0x50) &&
                     (buffer.data[0x73] == 0x31) &&
                     (buffer.data[0x74] == 0x37) &&
@@ -296,7 +311,7 @@ void Edid::applyEdidWorkArounds(NvU32 warFlag, const DpMonitorDenylistData *pDen
                 //    a "Monitor Description" of type FE = "ASCII Data String" which
                 //    has this panel's name = "LP154WX4-TLC3".
                 //
-                if ( (buffer.data[0x71] == 0x4C) &&
+                if ((buffer.data[0x71] == 0x4C) &&
                     (buffer.data[0x72] == 0x50) &&
                     (buffer.data[0x73] == 0x31) &&
                     (buffer.data[0x74] == 0x35) &&
@@ -504,15 +519,6 @@ void Edid::applyEdidWorkArounds(NvU32 warFlag, const DpMonitorDenylistData *pDen
             }
             break;
 
-        // Dell
-        case 0xAC10:
-            // Dell U2713H has problem with LQA. Disable it.
-            if ((ProductID == 0xA092) || (ProductID == 0xF046))
-            {
-                this->WARFlags.reassessMaxLink = true;
-            }
-            break;
-
         // CMN
         case 0xAE0D:
             if (ProductID == 0x1747)
@@ -584,12 +590,51 @@ void Edid::applyEdidWorkArounds(NvU32 warFlag, const DpMonitorDenylistData *pDen
 
         // Asus
         case 0x6D1E:
-            if(ProductID == 0x7707)
+            if (ProductID == 0x7707)
             {
                 this->WARFlags.bIgnoreDscCap = true;
                 DP_PRINTF(DP_NOTICE, "DP-WAR> Panel incorrectly exposing DSC capability. Ignoring it.");
                 DP_PRINTF(DP_NOTICE, "DP-WAR> Bug 3543158");
             }
+            else if (ProductID == 0x5B9A)
+            {
+                this->WARFlags.bDisableDscMaxBppLimit = true;
+                DP_PRINTF(DP_NOTICE, "DP-WAR> Disable DSC max BPP limit of 16 for DSC.");
+            }
+            break;
+        case 0xB306:
+            if (ProductID == 0x3228)
+            {
+                // ASUS PG32UQXR does not set DPCD 0x2217 to reflect correct CableID.
+                this->WARFlags.bSkipCableIdCheck = true;
+                DP_PRINTF(DP_NOTICE, "DP-WAR> Panel does not expose cable capability. Ignoring it. Bug 4968411");
+            }
+            else if(ProductID == 0x24b5 || ProductID == 0x32f2)
+            {
+                //
+                // Asus ROG PG248QP  (0x24b5) Bug 5100062
+                // Asus ROG PG32UCDM (0x32f2) Bug 5088957
+                //
+                this->WARFlags.bForceHeadShutdown = true;
+                DP_PRINTF(DP_NOTICE, "DP-WAR> Force head shutdown.");
+            }
+            break;
+
+        // Samsung
+        case 0x2D4C:
+            if (ProductID == 0x7474)
+            {
+                //
+                // Samsung Odyssey Neo 57 G9 needs manual allocation of timeslots when directly connected to upstream source
+                // Do not allocate manual timeslot when under a separate branch. This is checked with branch OUI.
+                //
+                this->WARFlags.bAllocateManualTimeslots = true;
+                DP_PRINTF(DP_NOTICE, "DP-WAR> Panel needs allocation of manual timeslot. Bug 4958974");
+            }
+            if (ProductID == 0x7256)
+            {
+                this->WARFlags.bDisableDownspread = true;
+            }
             break;
 
         default:
